Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1318)

Unified Diff: runtime/vm/intrinsifier_mips.cc

Issue 2005723004: Fraction class prototype and test (not to be committed). (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: work in progress Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/intrinsifier_ia32.cc ('k') | runtime/vm/intrinsifier_x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/intrinsifier_mips.cc
diff --git a/runtime/vm/intrinsifier_mips.cc b/runtime/vm/intrinsifier_mips.cc
index 748f06dff9d7bdda74aa590ac74a56fae2844ae1..a153f456d7368e3d3e6b1360cfaf1c5d1379783c 100644
--- a/runtime/vm/intrinsifier_mips.cc
+++ b/runtime/vm/intrinsifier_mips.cc
@@ -703,12 +703,13 @@ void Intrinsifier::Integer_equalToInteger(Assembler* assembler) {
__ andi(CMPRES1, T1, Immediate(kSmiTagMask));
__ bne(CMPRES1, ZR, &receiver_not_smi); // Check receiver.
// Left (receiver) is Smi, return false if right is not Double.
// Note that an instance of Mint or Bigint never contains a value that can be
// represented by Smi.
__ LoadClassId(CMPRES1, T0);
__ BranchEqual(CMPRES1, Immediate(kDoubleCid), &fall_through);
+ __ BranchEqual(CMPRES1, Immediate(kFractionCid), &fall_through);
__ LoadObject(V0, Bool::False()); // Smi == Mint -> false.
__ Ret();
« no previous file with comments | « runtime/vm/intrinsifier_ia32.cc ('k') | runtime/vm/intrinsifier_x64.cc » ('j') | no next file with comments »
@@ -703,12 +703,13 @@ void Intrinsifier::Integer_equalToInteger(Assembler* assembler) {
__ andi(CMPRES1, T1, Immediate(kSmiTagMask));
__ bne(CMPRES1, ZR, &receiver_not_smi); // Check receiver.
- // Left (receiver) is Smi, return false if right is not Double.
+ // Left (receiver) is Smi, return false if right is not Double or Fraction.
// Note that an instance of Mint or Bigint never contains a value that can be
// represented by Smi.

Powered by Google App Engine
This is Rietveld 408576698